@@ -147,7 +147,7 @@ function loadGISEditor(value, field, type, input_name, token) {
         'token' : token,
         'ajax_request': true
     }, function (data) {
-        if (data.success === true) {
+        if (typeof data !== 'undefined' && data.success === true) {
             $gis_editor.html(data.gis_editor);
             initGISEditorVisualization();
             prepareJSVersion();
@@ -197,7 +197,7 @@ function insertDataAndClose() {
     var input_name = $form.find("input[name='input_name']").val();
 
     $.post('gis_data_editor.php', $form.serialize() + "&generate=true&ajax_request=true", function (data) {
-        if (data.success === true) {
+        if (typeof data !== 'undefined' && data.success === true) {
             $("input[name='" + input_name + "']").val(data.result);
         } else {
             PMA_ajaxShowMessage(data.error, false);
@@ -248,10 +248,11 @@ AJAX.registerOnload('gis_data_editor.js', function () {
     $('#gis_editor').find("input[type='text']").live('change', function () {
         var $form = $('form#gis_data_editor_form');
         $.post('gis_data_editor.php', $form.serialize() + "&generate=true&ajax_request=true", function (data) {
-            if (data.success === true) {
+            if (typeof data !== 'undefined' && data.success === true) {
                 $('#gis_data_textarea').val(data.result);
                 $('#placeholder').empty().removeClass('hasSVG').html(data.visualization);
                 $('#openlayersmap').empty();
+                /* TODO: the gis_data_editor should rather return JSON than JS code to eval */
                 eval(data.openLayers);
                 initGISEditorVisualization();
             } else {
@@ -268,7 +269,7 @@ AJAX.registerOnload('gis_data_editor.js', function () {
         var $form = $('form#gis_data_editor_form');
 
         $.post('gis_data_editor.php', $form.serialize() + "&get_gis_editor=true&ajax_request=true", function (data) {
-            if (data.success === true) {
+            if (typeof data !== 'undefined' && data.success === true) {
                 $gis_editor.html(data.gis_editor);
                 initGISEditorVisualization();
                 prepareJSVersion();
